@@ -86,12 +86,20 @@ get_permission (const char *app_id,
       return UNSET;
     }
 
-  g_variant_lookup (out_perms, app_id, "^a&s", &permissions);
-  if (g_strv_length ((char **)permissions) != 1)
+  if (!g_variant_lookup (out_perms, app_id, "^a&s", &permissions))
     {
-      g_warning ("Wrong permission format, ignoring");
+      g_debug ("No permissions stored for: device %s, app %s", device, app_id);
+
       return UNSET;
     }
+  else if (g_strv_length ((char **)permissions) != 1)
+    {
+      g_autofree char *a = g_strjoinv (" ", (char **)permissions);
+      g_warning ("Wrong permission format, ignoring (%s)", a);
+      return UNSET;
+    }
+
+  g_debug ("permission store: device %s, app %s -> %s", device, app_id, permissions[0]);
 
   if (strcmp (permissions[0], "yes") == 0)
     return YES;
@@ -100,7 +108,10 @@ get_permission (const char *app_id,
   else if (strcmp (permissions[0], "ask") == 0)
     return ASK;
   else
-    g_warning ("Wrong permission format, ignoring");
+    {
+      g_autofree char *a = g_strjoinv (" ", (char **)permissions);
+      g_warning ("Wrong permission format, ignoring (%s)", a);
+    }
 
   return UNSET;
 }
@@ -224,6 +235,8 @@ handle_access_microphone_in_thread (GTask *task,
             subtitle = g_strdup_printf (_("%s wants to use your camera."), g_app_info_get_display_name (info));
         }
 
+      g_debug ("Calling backend for device access to: %s", device);
+
       if (!xdp_impl_access_call_access_dialog_sync (impl,
                                                     request->id,
                                                     app_id,
